@@ -10,13 +10,12 @@
 #  limitations under the License.
 """Module that defines the TableDiffParamsSetter class."""
 from ast import literal_eval
-from typing import List, Optional, Set, Union
-from urllib.parse import urlparse
+from typing import List, Optional, Set
 
 from metadata.data_quality.validations import utils
 from metadata.data_quality.validations.models import Column, TableDiffRuntimeParameters
 from metadata.data_quality.validations.runtime_param_setter.base_diff_params_setter import (
-    BaseTableParameter,
+    ServiceSpecPatch,
 )
 from metadata.data_quality.validations.runtime_param_setter.param_setter import (
     RuntimeParameterSetter,
@@ -25,23 +24,8 @@ from metadata.generated.schema.entity.data.table import Constraint, Table
 from metadata.generated.schema.entity.services.databaseService import DatabaseService
 from metadata.generated.schema.entity.services.serviceType import ServiceType
 from metadata.generated.schema.tests.testCase import TestCase
-from metadata.profiler.orm.registry import Dialects
 from metadata.utils import fqn
 from metadata.utils.collections import CaseInsensitiveList
-from metadata.utils.importer import get_module_dir, import_from_module
-
-
-def get_for_source(
-    service_type: ServiceType, source_type: str, from_: str = "ingestion"
-):
-    return import_from_module(
-        "metadata.{}.source.{}.{}.{}.ServiceSpec".format(  # pylint: disable=C0209
-            from_,
-            service_type.name.lower(),
-            get_module_dir(source_type),
-            "service_spec",
-        )
-    )
 
 
 class TableDiffParamsSetter(RuntimeParameterSetter):
@@ -64,37 +48,40 @@ class TableDiffParamsSetter(RuntimeParameterSetter):
         }
 
     def get_parameters(self, test_case) -> TableDiffRuntimeParameters:
-        # Using the specs class method causes circular import as TestSuiteInterface
-        # imports RuntimeParameterSetter
-        cls_path = get_for_source(
-            ServiceType.Database,
-            source_type=self.service_connection_config.type.value.lower(),
-        ).data_diff
-        cls = import_from_module(cls_path)()
-
         service1: DatabaseService = self.ometa_client.get_by_id(
             DatabaseService, self.table_entity.service.id, nullable=False
         )
 
-        service1_url = (
-            BaseTableParameter.get_service_connection_config(service1)
-            if self.service_connection_config
-            else None
-        )
-
         table2_fqn = self.get_parameter(test_case, "table2")
         if table2_fqn is None:
             raise ValueError("table2 not set")
+
         table2: Table = self.ometa_client.get_by_name(
             Table, fqn=table2_fqn, nullable=False
         )
         service2: DatabaseService = self.ometa_client.get_by_id(
             DatabaseService, table2.service.id, nullable=False
         )
+
+        service_spec_patch_table_1 = ServiceSpecPatch(
+            ServiceType.Database, service1.connection.config.type.value.lower()
+        )
+        data_diff_class_1 = service_spec_patch_table_1.get_data_diff_class()()
+        service_spec_patch_table_2 = ServiceSpecPatch(
+            ServiceType.Database, service2.connection.config.type.value.lower()
+        )
+        data_diff_class_2 = service_spec_patch_table_2.get_data_diff_class()()
+
+        service1_url = data_diff_class_1._get_service_connection_config(
+            service1.connection.config
+        )
         service2_url = (
             self.get_parameter(test_case, "service2Url") or service1_url
             if table2.service == self.table_entity.service
-            else None
+            else data_diff_class_2._get_service_connection_config(
+                service2.connection.config
+            )
+            or None
         )
 
         key_columns = self.get_key_columns(test_case)
@@ -113,7 +100,7 @@ class TableDiffParamsSetter(RuntimeParameterSetter):
 
         return TableDiffRuntimeParameters(
             table_profile_config=self.table_entity.tableProfilerConfig,
-            table1=cls.get(
+            table1=data_diff_class_1.get(
                 service1,
                 self.table_entity,
                 key_columns,
@@ -121,7 +108,7 @@ class TableDiffParamsSetter(RuntimeParameterSetter):
                 case_sensitive_columns,
                 service1_url,
             ),
-            table2=cls.get(
+            table2=data_diff_class_2.get(
                 service2,
                 table2,
                 key_columns,
@@ -211,45 +198,6 @@ class TableDiffParamsSetter(RuntimeParameterSetter):
             (p.value for p in test_case.parameterValues if p.name == key), default
         )
 
-    @staticmethod
-    def get_data_diff_url(
-        db_service: DatabaseService, table_fqn, override_url: Optional[str] = None
-    ) -> Union[str, dict]:
-        """Get the url for the data diff service.
-
-        Args:
-            db_service (DatabaseService): The database service entity
-            table_fqn (str): The fully qualified name of the table
-            override_url (Optional[str], optional): Override the url. Defaults to None.
-
-        Returns:
-            str: The url for the data diff service
-        """
-        source_url = (
-            BaseTableParameter.get_service_connection_config(db_service)
-            if not override_url
-            else override_url
-        )
-        if isinstance(source_url, dict):
-            source_url["driver"] = source_url["driver"].split("+")[0]
-            return source_url
-
-        url = urlparse(source_url)
-        # remove the driver name from the url because table-diff doesn't support it
-        kwargs = {"scheme": url.scheme.split("+")[0]}
-        service, database, schema, table = fqn.split(  # pylint: disable=unused-variable
-            table_fqn
-        )
-        # path needs to include the database AND schema in some of the connectors
-        if hasattr(db_service.connection.config, "supportsDatabase"):
-            kwargs["path"] = f"/{database}"
-        # this can be found by going to:
-        # https://github.com/open-metadata/collate-data-diff/blob/main/data_diff/databases/<connector>.py
-        # and looking at the `CONNECT_URI_HELPER` variable
-        if kwargs["scheme"] in {Dialects.MSSQL, Dialects.Snowflake, Dialects.Trino}:
-            kwargs["path"] = f"/{database}/{schema}"
-        return url._replace(**kwargs).geturl()
-
     @staticmethod
     def get_data_diff_table_path(table_fqn: str) -> str:
         service, database, schema, table = fqn.split(  # pylint: disable=unused-variable
