@@ -69,7 +69,6 @@ from metadata.generated.schema.entity.data.dashboardDataModel import (
 )
 from metadata.generated.schema.entity.data.table import Column, Table
 from metadata.generated.schema.entity.services.connections.dashboard.lookerConnection import (
-    LocalRepositoryPath,
     LookerConnection,
     NoGitCredentials,
 )
@@ -244,43 +243,29 @@ class LookerSource(DashboardServiceSource):
         credentials: Optional[
             Union[
                 NoGitCredentials,
-                LocalRepositoryPath,
                 GitHubCredentials,
                 BitBucketCredentials,
                 GitlabCredentials,
             ]
         ],
     ) -> "LookMLRepo":
-        if isinstance(credentials, LocalRepositoryPath):
-            # For local repository path, use the path directly without cloning
-            local_path = Path(credentials.root)
-            repo_name = local_path.name
-            return LookMLRepo(name=repo_name, path=str(local_path))
-        elif isinstance(
-            credentials, (GitHubCredentials, BitBucketCredentials, GitlabCredentials)
-        ):
-            # For remote repositories, clone as before
-            repo_name = (
-                f"{credentials.repositoryOwner.root}/{credentials.repositoryName.root}"
-            )
-            repo_path = f"{REPO_TMP_LOCAL_PATH}/{credentials.repositoryName.root}"
-            _clone_repo(
-                repo_name,
-                repo_path,
-                credentials,
-                overwrite=True,
-            )
-            return LookMLRepo(name=repo_name, path=repo_path)
-        else:
-            # For NoGitCredentials or other unsupported types
-            raise ValueError(f"Unsupported credential type: {type(credentials)}")
+        repo_name = (
+            f"{credentials.repositoryOwner.root}/{credentials.repositoryName.root}"
+        )
+        repo_path = f"{REPO_TMP_LOCAL_PATH}/{credentials.repositoryName.root}"
+        _clone_repo(
+            repo_name,
+            repo_path,
+            credentials,
+            overwrite=True,
+        )
+        return LookMLRepo(name=repo_name, path=repo_path)
 
     def __read_manifest(
         self,
         credentials: Optional[
             Union[
                 NoGitCredentials,
-                LocalRepositoryPath,
                 GitHubCredentials,
                 BitBucketCredentials,
                 GitlabCredentials,
@@ -288,36 +273,21 @@ class LookerSource(DashboardServiceSource):
         ],
         path="manifest.lkml",
     ) -> Optional[LookMLManifest]:
-        file_path = Path(self._main_lookml_repo.path) / path
-        if not file_path.is_file():
-            if isinstance(credentials, LocalRepositoryPath):
-                logger.warning(
-                    f"Manifest file '{path}' not found in local repository at {file_path}. "
-                    f"Ensure the manifest file exists in your local LookML repository."
-                )
+        file_path = f"{self._main_lookml_repo.path}/{path}"
+        if not os.path.isfile(file_path):
             return None
-
         with open(file_path, "r", encoding="utf-8") as fle:
             manifest = LookMLManifest.model_validate(lkml.load(fle))
             if manifest and manifest.remote_dependency:
                 remote_name = manifest.remote_dependency["name"]
                 remote_git_url = manifest.remote_dependency["url"]
 
-                if isinstance(credentials, LocalRepositoryPath):
-                    # For local repository path, warn about remote dependencies
-                    logger.warning(
-                        f"Remote dependency '{remote_name}' found in manifest. "
-                        f"When using localRepositoryPath, remote dependencies are not automatically fetched. "
-                        f"If needed, manually place the dependency in the '{IMPORTED_PROJECTS_DIR}/{remote_name}' directory within your local repository."
-                    )
-                else:
-                    # For remote repositories, clone the dependency as before
-                    url_parsed = giturlparse.parse(remote_git_url)
-                    _clone_repo(
-                        f"{url_parsed.owner}/{url_parsed.repo}",  # pylint: disable=E1101
-                        f"{self._main_lookml_repo.path}/{IMPORTED_PROJECTS_DIR}/{remote_name}",
-                        credentials,
-                    )
+                url_parsed = giturlparse.parse(remote_git_url)
+                _clone_repo(
+                    f"{url_parsed.owner}/{url_parsed.repo}",  # pylint: disable=E1101
+                    f"{self._main_lookml_repo.path}/{IMPORTED_PROJECTS_DIR}/{remote_name}",
+                    credentials,
+                )
 
             return manifest
 
