@@ -1,5 +1,7 @@
 from typing import Optional, cast
 
+from sqlalchemy.engine.reflection import Inspector
+
 from metadata.generated.schema.entity.services.connections.database.exasolConnection import (
     ExasolConnection,
 )
@@ -9,6 +11,10 @@ from metadata.generated.schema.metadataIngestion.workflow import (
 from metadata.ingestion.api.steps import InvalidSourceException
 from metadata.ingestion.ometa.ometa_api import OpenMetadata
 from metadata.ingestion.source.database.common_db_source import CommonDbSourceService
+from metadata.utils.sqlalchemy_utils import get_all_table_ddls, get_table_ddl
+
+Inspector.get_all_table_ddls = get_all_table_ddls
+Inspector.get_table_ddl = get_table_ddl
 
 
 class ExasolSource(CommonDbSourceService):
