@@ -86,7 +86,9 @@ class PythonDialects(Enum):
     SingleStore = "singlestore"
     SQLite = "sqlite"
     Snowflake = "snowflake"
+    Teradata = "teradatasql"
     Trino = "trino"
+    UnityCatalog = "unitycatalog"
     Vertica = "vertica"
 
 
